Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Extractors [][]*analysis.Analyzer
Extractors contains all schema extractors that will run.
It is a list of lists, where each list is a round of tasks dependent on the prior round's execution (e.g. an analyzer in Extractors[1] will only execute once all analyzers in Extractors[0] complete). Elements of the same list should be considered unordered and may run in parallel.
Functions ¶
This section is empty.
Types ¶
type NativeNames ¶ added in v0.305.0
NativeNames is a map of top-level declarations to their native Go names.
type Result ¶ added in v0.261.0
type Result struct {
// Module is the extracted module schema.
Module *schema.Module
// NativeNames maps schema nodes to their native Go names.
NativeNames NativeNames
// Errors is a list of errors encountered during schema extraction.
Errors []*schema.Error
}
Result contains the final schema extraction result.
Click to show internal directories.
Click to hide internal directories.